@@ -8,7 +8,7 @@ package MarpaX::Languages::C::AST::Grammar;
 use MarpaX::Languages::C::AST::Grammar::ISO_ANSI_C_2011;
 use Carp qw/croak/;
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 sub new {
@@ -60,7 +60,7 @@ MarpaX::Languages::C::AST::Grammar - C grammar written in Marpa BNF
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -106,6 +106,20 @@ L<Marpa::R2>, L<MarpaX::Languages::C::AST::Grammar::ISO_ANSI_C_2011>
 
 Jean-Damien Durand <jeandamiendurand@free.fr>
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Jeffrey Kegler <jkegl@cpan.org>
+
+=item *
+
+jddurand <jeandamiendurand@free.fr>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Jean-Damien Durand.
